@@ -1,6 +1,6 @@
 import pytest
 
-from report_generator.report import Report
+from numerous_report_generator.report import Report
 
 def uploader(filename, file_id):
     pass
