@@ -1,6 +1,6 @@
 import pytest
 import pandas as pd
-from report_generator.report_utils import create_download_link
+from numerous_report_generator.report_utils import create_download_link
 
 def test_create_download_link():
     df = pd.DataFrame({'a': [0,1,2]})
